@@ -1,3 +1,4 @@
+# coding=utf-8
 # This file is part of QNET.
 #
 # QNET is free software: you can redistribute it and/or modify
@@ -38,7 +39,6 @@ import qutip
 
 import qnet.algebra.abstract_algebra
 from qnet.algebra.hilbert_space_algebra import *
-from qnet.algebra.permutations import *
 
 
 #noinspection PyUnresolvedReferences
@@ -975,7 +975,8 @@ class OperatorTimes(OperatorOperation):
 
     def _tex(self):
         ret = self.operands[0].tex()
-        for o in self.operands[1:]:
+        # for o in self.operands[1:]:
+        for o in self.operands:
             if isinstance(o, OperatorPlus):
                 ret += r" \left({}\right) ".format(tex(o))
             else:
@@ -983,12 +984,18 @@ class OperatorTimes(OperatorOperation):
         return ret
 
     def __str__(self):
-        ret = str(self.operands[0])
-        for o in self.operands[1:]:
+        # ret = str(self.operands[0])
+        # for o in self.operands[1:]:
+        #     if isinstance(o, OperatorPlus):
+        #         ret += r" ({})".format(str(o))
+        #     else:
+        #         ret += " {}".format(str(o))
+        for o in self.operands:
             if isinstance(o, OperatorPlus):
-                ret += r" ({})".format(str(o))
+                ret += r" ({}) ".format(str(o))
             else:
                 ret += " {}".format(str(o))
+
         return ret
 
 
